from kubernetes import client, config
from kubernetes.client import configuration
import time

def get_deployment_metrics():
    configuration.assert_hostname = False
    config.load_kube_config()  # Load Kubernetes configuration from default location
    configuration.assert_hostname = False
    api_instance = client.CustomObjectsApi()

    # Retrieve metrics of all deployments in the "default" namespace
    deployments_metrics = api_instance.list_namespaced_custom_object(
        group="metrics.k8s.io",
        version="v1beta1",
        namespace="default",
        plural="deployments"
    )

    deployment_metrics_info = []
    for deployment in deployments_metrics["items"]:
        deployment_name = deployment["metadata"]["name"]
        replicas = deployment["spec"]["replicas"]
        ready_replicas = deployment["status"]["readyReplicas"]
        unavailable_replicas = replicas - ready_replicas if ready_replicas is not None else 0
        deployment_metrics_info.append((deployment_name, replicas, ready_replicas, unavailable_replicas))

    return deployment_metrics_info

def display_dashboard(deployment_metrics_info):
    print("Deployment Name\tReplicas\tReady Replicas\tUnavailable Replicas")
    print("-----------------------------------------------------------------")
    for deployment_name, replicas, ready_replicas, unavailable_replicas in deployment_metrics_info:
        print(f"{deployment_name}\t\t{replicas}\t\t{ready_replicas}\t\t{unavailable_replicas}")

def main():
    try:
        while True:
            deployment_metrics_info = get_deployment_metrics()
            display_dashboard(deployment_metrics_info)
            time.sleep(10)  # Wait for 10 seconds before refreshing
    except KeyboardInterrupt:
        print("\nMonitoring stopped.")

if __name__ == "__main__":
    main()

